@@ -15,6 +15,7 @@ from poetry.core.packages.package import Package
 from poetry.console.commands.installer_command import InstallerCommand
 from poetry.puzzle.exceptions import SolverProblemError
 from poetry.repositories.legacy_repository import LegacyRepository
+from poetry.utils.dependency_specification import RequirementsParser
 from tests.helpers import TestLocker
 from tests.helpers import get_dependency
 from tests.helpers import get_package
@@ -821,13 +822,16 @@ Writing lock file
     [
         (None, {"my-extra": ["cachy (==0.2.0)"]}),
         (
-            {"other": ["foo>2"]},
-            {"other": ["foo>2"], "my-extra": ["cachy (==0.2.0)"]},
+            {"other": ["tomlkit (<2)"]},
+            {"other": ["tomlkit (<2)"], "my-extra": ["cachy (==0.2.0)"]},
         ),
-        ({"my-extra": ["foo>2"]}, {"my-extra": ["foo>2", "cachy (==0.2.0)"]}),
         (
-            {"my-extra": ["foo>2", "cachy (==0.1.0)", "bar>1"]},
-            {"my-extra": ["foo>2", "cachy (==0.2.0)", "bar>1"]},
+            {"my-extra": ["tomlkit (<2)"]},
+            {"my-extra": ["tomlkit (<2)", "cachy (==0.2.0)"]},
+        ),
+        (
+            {"my-extra": ["tomlkit (<2)", "cachy (==0.1.0)", "pendulum (>1)"]},
+            {"my-extra": ["tomlkit (<2)", "cachy (==0.2.0)", "pendulum (>1)"]},
         ),
     ],
 )
@@ -840,29 +844,22 @@ def test_add_constraint_with_optional(
 ) -> None:
     pyproject: dict[str, Any] = app.poetry.file.read()
     if project_dependencies:
-        pyproject["project"]["dependencies"] = ["foo>1"]
+        pyproject["project"]["dependencies"] = ["tomlkit (<1)"]
         if existing_extras:
             pyproject["project"]["optional-dependencies"] = existing_extras
     else:
-        pyproject["tool"]["poetry"]["dependencies"]["foo"] = "^1.0"
+        pyproject["tool"]["poetry"]["dependencies"]["tomlkit"] = "<1"
     pyproject = cast("TOMLDocument", pyproject)
     app.poetry.file.write(pyproject)
+    app.reset_poetry()
 
     tester.execute("cachy=0.2.0 --optional my-extra")
-    expected = """\
 
-Updating dependencies
-Resolving dependencies...
-
-No dependencies to install or update
-
-Writing lock file
-"""
-
-    assert tester.io.fetch_output() == expected
+    assert tester.io.fetch_output().endswith("Writing lock file\n")
     assert isinstance(tester.command, InstallerCommand)
-    assert tester.command.installer.executor.installations_count == 0
+    assert tester.command.installer.executor.installations_count > 0
 
+    # check pyproject content
     pyproject2: dict[str, Any] = app.poetry.file.read()
     project_content = pyproject2["project"]
     poetry_content = pyproject2["tool"]["poetry"]
@@ -886,6 +883,24 @@ Writing lock file
             in tester.io.fetch_error()
         )
 
+    # check lock content
+    if project_dependencies:
+        lock_data = app.poetry.locker.lock_data
+
+        extras = lock_data["extras"]
+        assert list(extras) == sorted(expected_extras)
+        assert extras["my-extra"] == sorted(
+            e.split(" ")[0] for e in expected_extras["my-extra"]
+        )
+
+        added_package: dict[str, Any] | None = None
+        for package in lock_data["package"]:
+            if package["name"] == "cachy":
+                added_package = package
+                break
+        assert added_package is not None
+        assert added_package.get("markers") == 'extra == "my-extra"'
+
 
 def test_add_constraint_with_optional_not_main_group(
     app: PoetryTestApplication, tester: CommandTester
@@ -1093,7 +1108,7 @@ def test_add_creating_poetry_section_does_not_remove_existing_tools(
     poetry = project_factory(
         name="foobar",
         pyproject_content=(
-            '[project]\nname = "foobar"\nversion="0"\n' '[tool.foo]\nkey = "value"\n'
+            '[project]\nname = "foobar"\nversion="0"\n[tool.foo]\nkey = "value"\n'
         ),
     )
     tester = command_tester_factory("add", poetry=poetry)
@@ -1245,6 +1260,21 @@ def test_add_should_fail_circular_dependency(
     assert expected in tester.io.fetch_error()
 
 
+def test_add_latest_should_strip_out_invalid_pep508_path(
+    tester: CommandTester, repo: TestRepository, mocker: MockerFixture
+) -> None:
+    spy = mocker.spy(RequirementsParser, "parse")
+    repo.add_package(get_package("foo", "1.1.1"))
+    repo.add_package(get_package("foo", "1.1.2"))
+    tester.execute("foo@latest")
+
+    assert tester.status_code == 0
+    assert "Using version ^1.1.2 for foo" in tester.io.fetch_output()
+
+    assert spy.call_count == 1
+    assert spy.call_args_list[0].args[1] == "foo"
+
+
 @pytest.mark.parametrize("project_dependencies", [True, False])
 def test_add_latest_should_not_create_duplicate_keys(
     project_factory: ProjectFactory,
